package com.huimv.guowei.admin.controller;


import com.alibaba.druid.util.StringUtils;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.guowei.admin.common.utils.Result;
import com.huimv.guowei.admin.common.utils.ResultCode;
import com.huimv.guowei.admin.entity.EnvDevice;
import com.huimv.guowei.admin.entity.EnvDeviceEquipment;
import com.huimv.guowei.admin.service.IEnvDeviceEquipmentService;
import com.huimv.guowei.admin.service.IEnvDeviceService;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.interceptor.TransactionAspectSupport;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Map;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author author
 * @since 2023-06-01
 */
@RestController
@RequestMapping("/env-device")
@CrossOrigin
public class EnvDeviceController {
    @Resource
    private IEnvDeviceService envDeviceService;
    @Resource
    private IEnvDeviceEquipmentService envDeviceEquipmentService;
    @PostMapping("/listDevice")
    public Result listDevice(@RequestBody Map<String ,String> paramsMap){
        String deviceType = paramsMap.get("deviceType");
        String farmId = paramsMap.get("farmId");
        String pageNo = paramsMap.get("pageNum");
        String pageSize = paramsMap.get("pageSize");
        Page<EnvDevice> page = new Page(Integer.parseInt(pageNo),Integer.parseInt(pageSize));

        return new Result(ResultCode.SUCCESS,envDeviceService.page(page, new QueryWrapper<EnvDevice>()
                        .eq(!StringUtils.isEmpty(deviceType),"device_type",deviceType)
                        .eq("farm_id",farmId)));
    }

    @PostMapping("/listScale")
    public Result listScale(@RequestBody Map<String ,String> paramsMap){
        String farmId = paramsMap.get("farmId");
        return new Result(ResultCode.SUCCESS,envDeviceService.list(new QueryWrapper<EnvDevice>().eq("farm_id",farmId).eq("device_type",2)));
    }

    @PostMapping("/addDevice")
    @Transactional(rollbackFor = RuntimeException.class)
    public Result addDevice(@RequestBody Map<String ,Object> paramsMap){
        String deviceCode = (String) paramsMap.get("deviceCode");
        Integer unitId = (Integer) paramsMap.get("unitId");
        String unitName = (String) paramsMap.get("unitName");
        Integer farmId = (Integer) paramsMap.get("farmId");
        Integer deviceType = (Integer) paramsMap.get("deviceType");
        String deviceName = unitName;
        switch (deviceType){
            case 1: deviceName += "环控";
            break;
            case 2: deviceName += "移动电子秤";
            break;
            case 3: deviceName += "固定电子秤";
            break;
        }
        EnvDevice envDevice = new EnvDevice();
        envDevice.setDeviceCode(deviceCode);
        envDevice.setDeviceName(deviceName);
        envDevice.setDeviceType(deviceType);
        if (deviceType != 3){
            envDevice.setUnitName(unitName);
            envDevice.setUnitId(unitId);
        }
        envDevice.setFarmId(farmId);
        envDeviceService.save(envDevice);
        //环控设备
        if (deviceType == 1){
            String device = (String) paramsMap.get("device");
            int fan = 1;
            int tp = 1;
            int spray = 1;
            for (int i = 0; i < device.length() ; i++) {
                EnvDeviceEquipment envDeviceEquipment = new EnvDeviceEquipment();
                envDeviceEquipment.setEquipmentPort(i+1);
                envDeviceEquipment.setUnitId(unitId);
                envDeviceEquipment.setDeviceCode(deviceCode);
                switch (device.charAt(i)){
                    case 1:
                        envDeviceEquipment.setEquipmentName("风机"+fan);
                        envDeviceEquipment.setDeviceAlias(unitName+"风机");
                        fan++;
                    break;
                    case 2:
                        envDeviceEquipment.setEquipmentName("传送带"+tp);
                        envDeviceEquipment.setDeviceAlias(unitName+"传送带");
                        tp++;
                    break;
                    case 3:
                        envDeviceEquipment.setEquipmentName("喷雾"+spray);
                        envDeviceEquipment.setDeviceAlias(unitName+"喷雾");
                        spray++;
                    break;
                }
                if (!envDeviceEquipmentService.save(envDeviceEquipment)) {
                    TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                    return new Result(10001,"操作失败",false);
                }
            }
        }
        return Result.SUCCESS();
    }

    @PostMapping("/deleteDevice")
    @Transactional
    public Result deleteDevice(@RequestBody Map<String ,String> paramsMap){
        String deviceCode = paramsMap.get("deviceCode");
        envDeviceService.remove(new QueryWrapper<EnvDevice>().eq("device_code",deviceCode));
        envDeviceEquipmentService.remove(new QueryWrapper<EnvDeviceEquipment>().eq("device_code",deviceCode));
        return Result.SUCCESS();
    }



}
